/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface CredentialsGcpConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.220.2/docs/resources/credentials_gcp#account_id CredentialsGcp#account_id}
    */
    readonly accountId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.220.2/docs/resources/credentials_gcp#auth_provider_x509_cert_url CredentialsGcp#auth_provider_x509_cert_url}
    */
    readonly authProviderX509CertUrl: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.220.2/docs/resources/credentials_gcp#auth_uri CredentialsGcp#auth_uri}
    */
    readonly authUri: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.220.2/docs/resources/credentials_gcp#client_email CredentialsGcp#client_email}
    */
    readonly clientEmail: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.220.2/docs/resources/credentials_gcp#client_id CredentialsGcp#client_id}
    */
    readonly clientId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.220.2/docs/resources/credentials_gcp#client_x509_cert_url CredentialsGcp#client_x509_cert_url}
    */
    readonly clientX509CertUrl: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.220.2/docs/resources/credentials_gcp#id CredentialsGcp#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.220.2/docs/resources/credentials_gcp#private_key CredentialsGcp#private_key}
    */
    readonly privateKey: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.220.2/docs/resources/credentials_gcp#private_key_id CredentialsGcp#private_key_id}
    */
    readonly privateKeyId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.220.2/docs/resources/credentials_gcp#project_id CredentialsGcp#project_id}
    */
    readonly projectId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.220.2/docs/resources/credentials_gcp#token_uri CredentialsGcp#token_uri}
    */
    readonly tokenUri: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.220.2/docs/resources/credentials_gcp#type CredentialsGcp#type}
    */
    readonly type: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/spotinst/spotinst/1.220.2/docs/resources/credentials_gcp spotinst_credentials_gcp}
*/
export declare class CredentialsGcp extends cdktf.TerraformResource {
    static readonly tfResourceType = "spotinst_credentials_gcp";
    /**
    * Generates CDKTF code for importing a CredentialsGcp resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the CredentialsGcp to import
    * @param importFromId The id of the existing CredentialsGcp that should be imported. Refer to the {@link https://registry.terraform.io/providers/spotinst/spotinst/1.220.2/docs/resources/credentials_gcp#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the CredentialsGcp to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/spotinst/spotinst/1.220.2/docs/resources/credentials_gcp spotinst_credentials_gcp} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options CredentialsGcpConfig
    */
    constructor(scope: Construct, id: string, config: CredentialsGcpConfig);
    private _accountId?;
    get accountId(): string;
    set accountId(value: string);
    get accountIdInput(): string | undefined;
    private _authProviderX509CertUrl?;
    get authProviderX509CertUrl(): string;
    set authProviderX509CertUrl(value: string);
    get authProviderX509CertUrlInput(): string | undefined;
    private _authUri?;
    get authUri(): string;
    set authUri(value: string);
    get authUriInput(): string | undefined;
    private _clientEmail?;
    get clientEmail(): string;
    set clientEmail(value: string);
    get clientEmailInput(): string | undefined;
    private _clientId?;
    get clientId(): string;
    set clientId(value: string);
    get clientIdInput(): string | undefined;
    private _clientX509CertUrl?;
    get clientX509CertUrl(): string;
    set clientX509CertUrl(value: string);
    get clientX509CertUrlInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _privateKey?;
    get privateKey(): string;
    set privateKey(value: string);
    get privateKeyInput(): string | undefined;
    private _privateKeyId?;
    get privateKeyId(): string;
    set privateKeyId(value: string);
    get privateKeyIdInput(): string | undefined;
    private _projectId?;
    get projectId(): string;
    set projectId(value: string);
    get projectIdInput(): string | undefined;
    private _tokenUri?;
    get tokenUri(): string;
    set tokenUri(value: string);
    get tokenUriInput(): string | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    get typeInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
