/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface OrganizationPolicyConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.220.2/docs/resources/organization_policy#description OrganizationPolicy#description}
    */
    readonly description?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.220.2/docs/resources/organization_policy#id OrganizationPolicy#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.220.2/docs/resources/organization_policy#name OrganizationPolicy#name}
    */
    readonly name: string;
    /**
    * policy_content block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.220.2/docs/resources/organization_policy#policy_content OrganizationPolicy#policy_content}
    */
    readonly policyContent: OrganizationPolicyPolicyContent[] | cdktf.IResolvable;
}
export interface OrganizationPolicyPolicyContentStatements {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.220.2/docs/resources/organization_policy#actions OrganizationPolicy#actions}
    */
    readonly actions: string[];
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.220.2/docs/resources/organization_policy#effect OrganizationPolicy#effect}
    */
    readonly effect: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.220.2/docs/resources/organization_policy#resources OrganizationPolicy#resources}
    */
    readonly resources: string[];
}
export declare function organizationPolicyPolicyContentStatementsToTerraform(struct?: OrganizationPolicyPolicyContentStatements | cdktf.IResolvable): any;
export declare function organizationPolicyPolicyContentStatementsToHclTerraform(struct?: OrganizationPolicyPolicyContentStatements | cdktf.IResolvable): any;
export declare class OrganizationPolicyPolicyContentStatementsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): OrganizationPolicyPolicyContentStatements | cdktf.IResolvable | undefined;
    set internalValue(value: OrganizationPolicyPolicyContentStatements | cdktf.IResolvable | undefined);
    private _actions?;
    get actions(): string[];
    set actions(value: string[]);
    get actionsInput(): string[] | undefined;
    private _effect?;
    get effect(): string;
    set effect(value: string);
    get effectInput(): string | undefined;
    private _resources?;
    get resources(): string[];
    set resources(value: string[]);
    get resourcesInput(): string[] | undefined;
}
export declare class OrganizationPolicyPolicyContentStatementsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: OrganizationPolicyPolicyContentStatements[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): OrganizationPolicyPolicyContentStatementsOutputReference;
}
export interface OrganizationPolicyPolicyContent {
    /**
    * statements block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.220.2/docs/resources/organization_policy#statements OrganizationPolicy#statements}
    */
    readonly statements: OrganizationPolicyPolicyContentStatements[] | cdktf.IResolvable;
}
export declare function organizationPolicyPolicyContentToTerraform(struct?: OrganizationPolicyPolicyContent | cdktf.IResolvable): any;
export declare function organizationPolicyPolicyContentToHclTerraform(struct?: OrganizationPolicyPolicyContent | cdktf.IResolvable): any;
export declare class OrganizationPolicyPolicyContentOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): OrganizationPolicyPolicyContent | cdktf.IResolvable | undefined;
    set internalValue(value: OrganizationPolicyPolicyContent | cdktf.IResolvable | undefined);
    private _statements;
    get statements(): OrganizationPolicyPolicyContentStatementsList;
    putStatements(value: OrganizationPolicyPolicyContentStatements[] | cdktf.IResolvable): void;
    get statementsInput(): cdktf.IResolvable | OrganizationPolicyPolicyContentStatements[] | undefined;
}
export declare class OrganizationPolicyPolicyContentList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: OrganizationPolicyPolicyContent[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): OrganizationPolicyPolicyContentOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/spotinst/spotinst/1.220.2/docs/resources/organization_policy spotinst_organization_policy}
*/
export declare class OrganizationPolicy extends cdktf.TerraformResource {
    static readonly tfResourceType = "spotinst_organization_policy";
    /**
    * Generates CDKTF code for importing a OrganizationPolicy resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the OrganizationPolicy to import
    * @param importFromId The id of the existing OrganizationPolicy that should be imported. Refer to the {@link https://registry.terraform.io/providers/spotinst/spotinst/1.220.2/docs/resources/organization_policy#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the OrganizationPolicy to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/spotinst/spotinst/1.220.2/docs/resources/organization_policy spotinst_organization_policy} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options OrganizationPolicyConfig
    */
    constructor(scope: Construct, id: string, config: OrganizationPolicyConfig);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _policyContent;
    get policyContent(): OrganizationPolicyPolicyContentList;
    putPolicyContent(value: OrganizationPolicyPolicyContent[] | cdktf.IResolvable): void;
    get policyContentInput(): cdktf.IResolvable | OrganizationPolicyPolicyContent[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
