/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface OrganizationUserGroupConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.220.2/docs/resources/organization_user_group#description OrganizationUserGroup#description}
    */
    readonly description?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.220.2/docs/resources/organization_user_group#id OrganizationUserGroup#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.220.2/docs/resources/organization_user_group#name OrganizationUserGroup#name}
    */
    readonly name: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.220.2/docs/resources/organization_user_group#user_ids OrganizationUserGroup#user_ids}
    */
    readonly userIds?: string[];
    /**
    * policies block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.220.2/docs/resources/organization_user_group#policies OrganizationUserGroup#policies}
    */
    readonly policies?: OrganizationUserGroupPolicies[] | cdktf.IResolvable;
}
export interface OrganizationUserGroupPolicies {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.220.2/docs/resources/organization_user_group#account_ids OrganizationUserGroup#account_ids}
    */
    readonly accountIds: string[];
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.220.2/docs/resources/organization_user_group#policy_id OrganizationUserGroup#policy_id}
    */
    readonly policyId: string;
}
export declare function organizationUserGroupPoliciesToTerraform(struct?: OrganizationUserGroupPolicies | cdktf.IResolvable): any;
export declare function organizationUserGroupPoliciesToHclTerraform(struct?: OrganizationUserGroupPolicies | cdktf.IResolvable): any;
export declare class OrganizationUserGroupPoliciesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): OrganizationUserGroupPolicies | cdktf.IResolvable | undefined;
    set internalValue(value: OrganizationUserGroupPolicies | cdktf.IResolvable | undefined);
    private _accountIds?;
    get accountIds(): string[];
    set accountIds(value: string[]);
    get accountIdsInput(): string[] | undefined;
    private _policyId?;
    get policyId(): string;
    set policyId(value: string);
    get policyIdInput(): string | undefined;
}
export declare class OrganizationUserGroupPoliciesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: OrganizationUserGroupPolicies[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): OrganizationUserGroupPoliciesOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/spotinst/spotinst/1.220.2/docs/resources/organization_user_group spotinst_organization_user_group}
*/
export declare class OrganizationUserGroup extends cdktf.TerraformResource {
    static readonly tfResourceType = "spotinst_organization_user_group";
    /**
    * Generates CDKTF code for importing a OrganizationUserGroup resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the OrganizationUserGroup to import
    * @param importFromId The id of the existing OrganizationUserGroup that should be imported. Refer to the {@link https://registry.terraform.io/providers/spotinst/spotinst/1.220.2/docs/resources/organization_user_group#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the OrganizationUserGroup to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/spotinst/spotinst/1.220.2/docs/resources/organization_user_group spotinst_organization_user_group} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options OrganizationUserGroupConfig
    */
    constructor(scope: Construct, id: string, config: OrganizationUserGroupConfig);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _userIds?;
    get userIds(): string[];
    set userIds(value: string[]);
    resetUserIds(): void;
    get userIdsInput(): string[] | undefined;
    private _policies;
    get policies(): OrganizationUserGroupPoliciesList;
    putPolicies(value: OrganizationUserGroupPolicies[] | cdktf.IResolvable): void;
    resetPolicies(): void;
    get policiesInput(): cdktf.IResolvable | OrganizationUserGroupPolicies[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
