/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface OrganizationUserConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.220.2/docs/resources/organization_user#email OrganizationUser#email}
    */
    readonly email: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.220.2/docs/resources/organization_user#first_name OrganizationUser#first_name}
    */
    readonly firstName: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.220.2/docs/resources/organization_user#id OrganizationUser#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.220.2/docs/resources/organization_user#last_name OrganizationUser#last_name}
    */
    readonly lastName: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.220.2/docs/resources/organization_user#password OrganizationUser#password}
    */
    readonly password?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.220.2/docs/resources/organization_user#role OrganizationUser#role}
    */
    readonly role?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.220.2/docs/resources/organization_user#user_group_ids OrganizationUser#user_group_ids}
    */
    readonly userGroupIds?: string[];
    /**
    * policies block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.220.2/docs/resources/organization_user#policies OrganizationUser#policies}
    */
    readonly policies?: OrganizationUserPolicies[] | cdktf.IResolvable;
}
export interface OrganizationUserPolicies {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.220.2/docs/resources/organization_user#policy_account_ids OrganizationUser#policy_account_ids}
    */
    readonly policyAccountIds: string[];
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.220.2/docs/resources/organization_user#policy_id OrganizationUser#policy_id}
    */
    readonly policyId: string;
}
export declare function organizationUserPoliciesToTerraform(struct?: OrganizationUserPolicies | cdktf.IResolvable): any;
export declare function organizationUserPoliciesToHclTerraform(struct?: OrganizationUserPolicies | cdktf.IResolvable): any;
export declare class OrganizationUserPoliciesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): OrganizationUserPolicies | cdktf.IResolvable | undefined;
    set internalValue(value: OrganizationUserPolicies | cdktf.IResolvable | undefined);
    private _policyAccountIds?;
    get policyAccountIds(): string[];
    set policyAccountIds(value: string[]);
    get policyAccountIdsInput(): string[] | undefined;
    private _policyId?;
    get policyId(): string;
    set policyId(value: string);
    get policyIdInput(): string | undefined;
}
export declare class OrganizationUserPoliciesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: OrganizationUserPolicies[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): OrganizationUserPoliciesOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/spotinst/spotinst/1.220.2/docs/resources/organization_user spotinst_organization_user}
*/
export declare class OrganizationUser extends cdktf.TerraformResource {
    static readonly tfResourceType = "spotinst_organization_user";
    /**
    * Generates CDKTF code for importing a OrganizationUser resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the OrganizationUser to import
    * @param importFromId The id of the existing OrganizationUser that should be imported. Refer to the {@link https://registry.terraform.io/providers/spotinst/spotinst/1.220.2/docs/resources/organization_user#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the OrganizationUser to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/spotinst/spotinst/1.220.2/docs/resources/organization_user spotinst_organization_user} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options OrganizationUserConfig
    */
    constructor(scope: Construct, id: string, config: OrganizationUserConfig);
    private _email?;
    get email(): string;
    set email(value: string);
    get emailInput(): string | undefined;
    private _firstName?;
    get firstName(): string;
    set firstName(value: string);
    get firstNameInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _lastName?;
    get lastName(): string;
    set lastName(value: string);
    get lastNameInput(): string | undefined;
    private _password?;
    get password(): string;
    set password(value: string);
    resetPassword(): void;
    get passwordInput(): string | undefined;
    private _role?;
    get role(): string;
    set role(value: string);
    resetRole(): void;
    get roleInput(): string | undefined;
    private _userGroupIds?;
    get userGroupIds(): string[];
    set userGroupIds(value: string[]);
    resetUserGroupIds(): void;
    get userGroupIdsInput(): string[] | undefined;
    private _policies;
    get policies(): OrganizationUserPoliciesList;
    putPolicies(value: OrganizationUserPolicies[] | cdktf.IResolvable): void;
    resetPolicies(): void;
    get policiesInput(): cdktf.IResolvable | OrganizationUserPolicies[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
